@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,10 +21,10 @@
 
 #include "DicomWebFormatter.h"
 
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 
-#if !defined(NDEBUG)
-#  include <json/reader.h>
+#if !defined(NDEBUG)  // In debug mode, check that the value is actually a JSON string
+#  include <Toolbox.h>
 #endif
 
 
@@ -126,7 +126,7 @@ namespace OrthancPlugins
 
   DicomWebFormatter::HttpWriter::HttpWriter(OrthancPluginRestOutput* output,
                                             bool isXml) :
-    context_(OrthancPlugins::GetGlobalContext()),
+    context_(GetGlobalContext()),
     output_(output),
     isXml_(isXml),
     first_(true)
@@ -163,8 +163,7 @@ namespace OrthancPlugins
 
     std::string item;
 
-    OrthancPlugins::DicomWebFormatter::Apply(
-      item, context_, dicom, size, isXml_, mode, bulkRoot);
+    DicomWebFormatter::Apply(item, context_, dicom, size, isXml_, mode, bulkRoot);
    
     if (isXml_)
     {
@@ -217,10 +216,8 @@ namespace OrthancPlugins
     }
 
 #if !defined(NDEBUG)  // In debug mode, check that the value is actually a JSON string
-    Json::Reader reader;
     Json::Value json;
-    if (!reader.parse(reinterpret_cast<const char*>(data),
-                      reinterpret_cast<const char*>(data) + size, json))
+    if (!OrthancPlugins::ReadJson(json, data, size))
     {
       throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat);
     }
