@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,7 +23,8 @@
 
 #include "Configuration.h"
 
-#include <Core/Toolbox.h>
+#include <Compatibility.h>
+#include <Toolbox.h>
 
 #include <boost/algorithm/string/predicate.hpp>
 
@@ -33,12 +34,15 @@ namespace OrthancPlugins
   {
     for (Servers::iterator it = servers_.begin(); it != servers_.end(); ++it)
     {
+      assert(it->second != NULL);
       delete it->second;
     }
+
+    servers_.clear();
   }
 
 
-  void DicomWebServers::Load(const Json::Value& servers)
+  void DicomWebServers::LoadGlobalConfiguration(const Json::Value& servers)
   {
     boost::mutex::scoped_lock lock(mutex_);
 
@@ -58,7 +62,7 @@ namespace OrthancPlugins
 
         for (size_t i = 0; i < members.size(); i++)
         {
-          std::auto_ptr<Orthanc::WebServiceParameters> parameters
+          std::unique_ptr<Orthanc::WebServiceParameters> parameters
             (new Orthanc::WebServiceParameters(servers[members[i]]));
 
           servers_[members[i]] = parameters.release();
@@ -67,8 +71,8 @@ namespace OrthancPlugins
     }
     catch (Orthanc::OrthancException& e)
     {
-      OrthancPlugins::LogError("Exception while parsing the \"DicomWeb.Servers\" section "
-                               "of the configuration file: " + std::string(e.What()));
+      LogError("Exception while parsing the \"DicomWeb.Servers\" section "
+               "of the configuration file: " + std::string(e.What()));
       throw;
     }
 
@@ -113,6 +117,7 @@ namespace OrthancPlugins
     servers.clear();
     for (Servers::const_iterator it = servers_.begin(); it != servers_.end(); ++it)
     {
+      assert(it->second != NULL);
       servers.push_back(it->first);
     }
   }
@@ -206,7 +211,7 @@ namespace OrthancPlugins
 
 
 
-  void CallServer(OrthancPlugins::MemoryBuffer& answerBody /* out */,
+  void CallServer(MemoryBuffer& answerBody /* out */,
                   std::map<std::string, std::string>& answerHeaders /* out */,
                   const Orthanc::WebServiceParameters& server,
                   OrthancPluginHttpMethod method,
@@ -270,7 +275,7 @@ namespace OrthancPlugins
       bodySize = body.size();
     }
 
-    OrthancPluginContext* context = OrthancPlugins::GetGlobalContext();
+    OrthancPluginContext* context = GetGlobalContext();
 
     uint16_t status = 0;
     MemoryBuffer answerHeadersTmp;
@@ -369,4 +374,51 @@ namespace OrthancPlugins
       }
     }
   }
+
+
+  void DicomWebServers::SerializeGlobalProperty(std::string& target)
+  {
+    boost::mutex::scoped_lock lock(mutex_);
+
+    Json::Value json = Json::objectValue;
+
+    for (Servers::const_iterator it = servers_.begin(); it != servers_.end(); ++it)
+    {
+      assert(it->second != NULL);
+
+      Json::Value server;
+      it->second->Serialize(server, true /* advanced format */, true /* store passwords */);
+      json[it->first] = server;
+    }
+
+    OrthancPlugins::WriteFastJson(target, json);
+  }
+
+
+  void DicomWebServers::UnserializeGlobalProperty(const std::string& source)
+  {
+    Json::Value json;
+    
+    if (!OrthancPlugins::ReadJson(json, source) ||
+        json.type() != Json::objectValue)
+    {
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat, "Cannot unserialize "
+                                      "the list of DICOMweb servers from global properties");
+    }
+
+    Clear();
+
+    std::vector<std::string> members = json.getMemberNames();
+    
+    for (size_t i = 0; i < members.size(); i++)
+    {
+      const std::string& name = members[i];
+      
+      std::unique_ptr<Orthanc::WebServiceParameters> server(new Orthanc::WebServiceParameters);
+      server->Unserialize(json[name]);
+
+      assert(servers_.find(name) == servers_.end());
+      servers_[name] = server.release();
+    }
+  }
 }
