@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -59,6 +59,16 @@ namespace OrthancPlugins
                                       "The STOW-RS plugin currently only supports \"application/dicom\" subtype");
     }
 
+    // Hotfix for bug #190, until the Orthanc Framework is fixed
+    // https://bugs.orthanc-server.com/show_bug.cgi?id=190
+    if (!boundary.empty() &&
+        boundary.size() >= 2 &&
+        boundary[0] == '"' &&
+        boundary[boundary.size() - 1] == '"')
+    {
+      boundary = boundary.substr(1, boundary.size() - 2);
+    }
+
     parser_.reset(new Orthanc::MultipartStreamReader(boundary));
     parser_->SetHandler(*this);
   }
@@ -149,7 +159,7 @@ namespace OrthancPlugins
       }
 
       MemoryBuffer tmp;
-      bool ok = tmp.RestApiPost("/instances", part, size, false);
+      ok = tmp.RestApiPost("/instances", part, size, false);
       tmp.Clear();
 
       if (ok)
