@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,8 +21,10 @@
 
 #pragma once
 
-#include <Core/HttpServer/MultipartStreamReader.h>
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
+
+#include <Compatibility.h>
+#include <HttpServer/MultipartStreamReader.h>
 
 namespace OrthancPlugins
 {
@@ -40,11 +42,11 @@ namespace OrthancPlugins
     Json::Value            success_;
     Json::Value            failed_;
 
-    std::auto_ptr<Orthanc::MultipartStreamReader>  parser_;
+    std::unique_ptr<Orthanc::MultipartStreamReader>  parser_;
 
     virtual void HandlePart(const Orthanc::MultipartStreamReader::HttpHeaders& headers,
                             const void* part,
-                            size_t size);
+                            size_t size) ORTHANC_OVERRIDE;
 
   public:
     StowServer(OrthancPluginContext* context,
@@ -52,9 +54,9 @@ namespace OrthancPlugins
                const std::string& expectedStudy);
 
     virtual void AddChunk(const void* data,
-                          size_t size);
+                          size_t size) ORTHANC_OVERRIDE;
 
-    virtual void Execute(OrthancPluginRestOutput* output);
+    virtual void Execute(OrthancPluginRestOutput* output) ORTHANC_OVERRIDE;
 
     static IChunkedRequestReader* PostCallback(const char* url,
                                                const OrthancPluginHttpRequest* request);
