@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,8 +21,9 @@
 
 #include "WadoRs.h"
 
-#include <Core/Toolbox.h>
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
+
+#include <Toolbox.h>
 
 #include <memory>
 #include <list>
@@ -120,9 +121,14 @@ static bool ParseTransferSyntax(Orthanc::DicomTransferSyntax& syntax,
           syntax = Orthanc::DicomTransferSyntax_LittleEndianImplicit;
           return true;
         }
+        else if (transferSyntax == "1.2.840.10008.1.2.2")  // New in 1.3
+        {
+          syntax = Orthanc::DicomTransferSyntax_BigEndianExplicit;
+          return false;
+        }        
         else if (transferSyntax == "*")
         {
-          // New in DICOMweb plugin 1.1.0
+          // New in DICOMweb plugin 1.1
           return false;
         }
         else
@@ -382,8 +388,6 @@ static void AnswerFrames(OrthancPluginRestOutput* output,
                                     "Cannot start a multipart answer");
   }
 
-  const std::string base = OrthancPlugins::Configuration::GetBaseUrl(request);
-    
   for (std::list<unsigned int>::const_iterator
          frame = frames.begin(); frame != frames.end(); ++frame)
   {
@@ -396,6 +400,7 @@ static void AnswerFrames(OrthancPluginRestOutput* output,
     OrthancPluginErrorCode error;
 
 #if HAS_SEND_MULTIPART_ITEM_2 == 1
+    const std::string base = OrthancPlugins::Configuration::GetBaseUrl(request);
     std::string location = (
       OrthancPlugins::Configuration::GetWadoUrl(base, studyInstanceUid, seriesInstanceUid, sopInstanceUid) +
       "frames/" + boost::lexical_cast<std::string>(*frame + 1));
@@ -454,6 +459,11 @@ static void RetrieveFrames(OrthancPluginRestOutput* output,
     else
     {
       instance.reset(new OrthancPlugins::DicomInstance(content.GetData(), content.GetSize()));
+      if (!Orthanc::LookupTransferSyntax(targetSyntax, instance->GetTransferSyntaxUid()))
+      {
+        throw Orthanc::OrthancException(Orthanc::ErrorCode_NotImplemented,
+                                        "Unknown transfer syntax: " + std::string(GetTransferSyntaxUid(targetSyntax)));
+      }
     }
 
     if (instance.get() == NULL)
