@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -20,11 +20,13 @@
 
 #include "WadoRs.h"
 
-#include <Core/Images/Image.h>
-#include <Core/Images/ImageProcessing.h>
-#include <Core/Images/ImageTraits.h>
-#include <Core/Toolbox.h>
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
+
+#include <Images/Image.h>
+#include <Images/ImageProcessing.h>
+#include <Images/ImageTraits.h>
+#include <Logging.h>
+#include <Toolbox.h>
 
 #include <boost/algorithm/string/predicate.hpp>
 #include <boost/math/special_functions/round.hpp>
@@ -598,7 +600,8 @@ static void ApplyWindowing(Orthanc::ImageAccessor& target,
 
 static void ApplyRendering(Orthanc::ImageAccessor& target,
                            const Orthanc::ImageAccessor& source,
-                           const RenderingParameters& parameters)
+                           const RenderingParameters& parameters,
+                           bool invert)
 {
   Orthanc::ImageProcessing::Set(target, 0);
 
@@ -624,6 +627,14 @@ static void ApplyRendering(Orthanc::ImageAccessor& target,
     {
       switch (source.GetFormat())
       {
+        case Orthanc::PixelFormat_Grayscale8:
+          ApplyWindowing<Orthanc::PixelFormat_Grayscale8>(scaled, region, parameters.GetWindowCenter(),
+                                                          parameters.GetWindowWidth(),
+                                                          parameters.GetWindowingMode(),
+                                                          parameters.GetRescaleSlope(),
+                                                          parameters.GetRescaleIntercept());
+          break;
+
         case Orthanc::PixelFormat_Grayscale16:
           ApplyWindowing<Orthanc::PixelFormat_Grayscale16>(scaled, region, parameters.GetWindowCenter(),
                                                            parameters.GetWindowWidth(),
@@ -661,6 +672,10 @@ static void ApplyRendering(Orthanc::ImageAccessor& target,
     Orthanc::ImageProcessing::FlipY(scaled);
   }
 
+  if (invert)
+  {
+    Orthanc::ImageProcessing::Invert(scaled);
+  }
 
   // TODO => Replace what follows with a call to "Orthanc::ImageProcessing::FitSize()"
 
@@ -697,6 +712,7 @@ static void AnswerFrameRendered(OrthancPluginRestOutput* output,
 {
   static const char* const RESCALE_INTERCEPT = "0028,1052";
   static const char* const RESCALE_SLOPE = "0028,1053";
+  static const char* const PHOTOMETRIC_INTERPRETATION = "0028,0004";
 
   Orthanc::MimeType mime = Orthanc::MimeType_Jpeg;  // This is the default in DICOMweb
       
@@ -795,8 +811,22 @@ static void AnswerFrameRendered(OrthancPluginRestOutput* output,
       Orthanc::Image target(targetFormat, parameters.GetTargetWidth(source.GetWidth()),
                             parameters.GetTargetHeight(source.GetHeight()), false);
 
-      ApplyRendering(target, source, parameters);
-          
+      // New in 1.3: Fix for MONOCHROME1 images
+      bool invert = false;
+      if (target.GetFormat() == Orthanc::PixelFormat_Grayscale8 &&
+          tags.isMember(PHOTOMETRIC_INTERPRETATION) &&
+          tags[PHOTOMETRIC_INTERPRETATION].type() == Json::stringValue)
+      {
+        std::string s = tags[PHOTOMETRIC_INTERPRETATION].asString();
+        Orthanc::Toolbox::StripSpaces(s);
+        if (s == "MONOCHROME1")
+        {
+          invert = true;
+        }
+      }
+      
+      ApplyRendering(target, source, parameters, invert);
+
       switch (mime)
       {
         case Orthanc::MimeType_Png:
@@ -822,10 +852,19 @@ static void AnswerFrameRendered(OrthancPluginRestOutput* output,
     std::map<std::string, std::string> headers;
     headers["Accept"] = Orthanc::EnumerationToString(mime);
 
-    // In DICOMweb, the "frame" parameter is in the range [1..N],
-    // whereas Orthanc uses range [0..N-1], hence the "-1" below.
+    /**
+     * (1) In DICOMweb, the "frame" parameter is in the range [1..N],
+     * whereas Orthanc uses range [0..N-1], hence the "-1" below.
+     * 
+     * (2) We can use "/rendered" that was introduced in the REST API
+     * of Orthanc 1.6.0, as since release 1.2 of the DICOMweb plugin,
+     * the minimal SDK version is Orthanc 1.7.0 (in order to be able
+     * to use transcoding primitives). In releases <= 1.2, "/preview"
+     * was used, which caused one issue:
+     * https://groups.google.com/d/msg/orthanc-users/mKgr2QAKTCU/R7u4I1LvBAAJ
+     **/
     if (buffer.RestApiGet("/instances/" + instanceId + "/frames/" +
-                          boost::lexical_cast<std::string>(frame - 1) + "/preview", headers, false))
+                          boost::lexical_cast<std::string>(frame - 1) + "/rendered", headers, false))
     {
       OrthancPluginAnswerBuffer(OrthancPlugins::GetGlobalContext(), output, buffer.GetData(),
                                 buffer.GetSize(), Orthanc::EnumerationToString(mime));
