@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,6 +24,7 @@
 #include <boost/algorithm/string/predicate.hpp>
 
 #include "../Plugin/Configuration.h"
+#include "../Plugin/DicomWebServers.h"
 
 using namespace OrthancPlugins;
 
@@ -61,6 +62,50 @@ TEST(ContentType, Parse)
 }
 
 
+TEST(DicomWebServers, Serialization)
+{
+  std::list<std::string> servers;
+  DicomWebServers::GetInstance().ListServers(servers);
+  ASSERT_TRUE(servers.empty());
+
+  {
+    std::string json;
+    DicomWebServers::GetInstance().SerializeGlobalProperty(json);
+    DicomWebServers::GetInstance().UnserializeGlobalProperty(json);
+    ASSERT_TRUE(servers.empty());
+  }
+
+  Orthanc::WebServiceParameters p;
+  p.SetUrl("http://hello/");
+  p.SetCredentials("user", "world");
+  DicomWebServers::GetInstance().SetServer("test", p);
+
+  std::string json;
+  DicomWebServers::GetInstance().SerializeGlobalProperty(json);
+
+  p.SetUrl("http://nope/");
+  p.ClearCredentials();
+  DicomWebServers::GetInstance().SetServer("nope", p);
+
+  DicomWebServers::GetInstance().ListServers(servers);
+  ASSERT_EQ(2u, servers.size());
+  
+  DicomWebServers::GetInstance().UnserializeGlobalProperty(json);
+
+  DicomWebServers::GetInstance().ListServers(servers);
+  ASSERT_EQ(1u, servers.size());
+
+  ASSERT_THROW(DicomWebServers::GetInstance().GetServer("nope"), Orthanc::OrthancException);
+  p = DicomWebServers::GetInstance().GetServer("test");
+  ASSERT_EQ("http://hello/", p.GetUrl());
+  ASSERT_EQ("user", p.GetUsername());
+
+  DicomWebServers::GetInstance().Clear();
+  DicomWebServers::GetInstance().ListServers(servers);
+  ASSERT_TRUE(servers.empty());
+}
+
+
 int main(int argc, char **argv)
 {
   ::testing::InitGoogleTest(&argc, argv);
